vscodiumbuildpack

package module
v0.0.0-...-9f89a74 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Oct 30, 2025 License: Apache-2.0 Imports: 13 Imported by: 0

README

VSCodium Buildpack

A buildpack that packages browser based vscodium into an image.

To build and run this buildpack, run

# build the buildpack
$ make build
# create a docker image using the buildpack and an application directory
$ pack build vscodium --path <application root dir> --buildpack . --builder paketobuildpacks/builder-jammy-base --verbose
# run the built image
$ docker run -u 1001 -p 8000:8000 -e HOME=/workspace -it --rm vscodium 

Note that since this buildpack does not actually inspect the application, the application root dir can be just an empty folder.

Test

You can run the tests with make test.

Packaging

To create a package (.cnb file) run make package version=<version> (with "" being something like 1.2.3).

Documentation

Index

Constants

const (
	VSCODIUM = "vscodium"
	DepKey   = "dependency-sha"
)
const RenkuFrontendEnvKey = "BP_RENKU_FRONTENDS"

NOTE: According to the spec if the env variable is not preceeded with BP_ then the env variable can be overwritten by the lifecycle. https://github.com/buildpacks/spec/blob/main/buildpack.md#provided-by-the-platform

const RenkuFrontendEnvValue = "vscodium"

Variables

This section is empty.

Functions

func Build

func Build(
	dependencyService DependencyService,
	calculator ChecksumCalculator,
	sbomGenerator SBOMGenerator,
	logger scribe.Emitter,
	clock chronos.Clock,
) packit.BuildFunc

func Detect

func Detect(versionParser VersionParser) packit.DetectFunc

Types

type BuildPlanMetadata

type BuildPlanMetadata struct {
	Version       string `toml:"version,omitempty"`
	VersionSource string `toml:"version-source,omitempty"`
	Launch        bool   `toml:"launch"`
}

type ChecksumCalculator

type ChecksumCalculator interface {
	Sum(paths ...string) (string, error)
}

type DependencyService

type DependencyService interface {
	Resolve(path, name, version, stack string) (postal.Dependency, error)
	Deliver(dependency postal.Dependency, cnbPath, layerPath, platformPath string) error
	GenerateBillOfMaterials(dependencies ...postal.Dependency) []packit.BOMEntry
}

type Parser

type Parser struct{}

func NewParser

func NewParser() Parser

func (Parser) ResolveVersion

func (p Parser) ResolveVersion(cnbPath, version string) (string, error)

type SBOMGenerator

type SBOMGenerator interface {
	GenerateFromDependency(dependency postal.Dependency, dir string) (sbom.SBOM, error)
}

type VersionParser

type VersionParser interface {
	ResolveVersion(cnbPath, version string) (resultVersion string, err error)
}

Directories

Path Synopsis
cmd

Jump to