Documentation
¶
Index ¶
Constants ¶
const ( VSCODIUM = "vscodium" DepKey = "dependency-sha" )
const RenkuFrontendEnvKey = "BP_RENKU_FRONTENDS"
NOTE: According to the spec if the env variable is not preceeded with BP_ then the env variable can be overwritten by the lifecycle. https://github.com/buildpacks/spec/blob/main/buildpack.md#provided-by-the-platform
const RenkuFrontendEnvValue = "vscodium"
Variables ¶
This section is empty.
Functions ¶
func Build ¶
func Build( dependencyService DependencyService, calculator ChecksumCalculator, sbomGenerator SBOMGenerator, logger scribe.Emitter, clock chronos.Clock, ) packit.BuildFunc
func Detect ¶
func Detect(versionParser VersionParser) packit.DetectFunc
Types ¶
type BuildPlanMetadata ¶
type ChecksumCalculator ¶
type DependencyService ¶
type DependencyService interface {
Resolve(path, name, version, stack string) (postal.Dependency, error)
Deliver(dependency postal.Dependency, cnbPath, layerPath, platformPath string) error
GenerateBillOfMaterials(dependencies ...postal.Dependency) []packit.BOMEntry
}
type SBOMGenerator ¶
type VersionParser ¶
Click to show internal directories.
Click to hide internal directories.